@@ -34,7 +34,7 @@ use Crypt::Rabbit;
 use Crypt::RC4::XS;
 use Crypt::Spritz;
 use Digest::MD5;
-use Net::SSLeay;
+#use Net::SSLeay;
 #use Digest::SHA;
 #use Mcrypt qw(:FUNCS);
 #use String::HexConvert ':all';
@@ -266,7 +266,7 @@ sub _get_algorithm($)
     }
     else
     {
-        return 'arcfour';
+        return 'spritz';
     }
     }
 
@@ -386,7 +386,7 @@ Shadowsocks is a secure transport protocol based on SOCKS Protocol Version 5 (RF
 
 2.The following ciphers deprecated by Shadowsocks are not supported: 
 
-      bf-cfb chacha20 salsa20 rc4-md5
+      bf-cfb chacha20 salsa20 
 
 3.The following ciphers recommended by Shadowsocks are not supported yet: 
  
